@@ -5,15 +5,17 @@ use std::path::Path;
 pub struct Workspace {
     path_to_config: String,
     scope: String,
+    ignore_queue: bool,
     db: Database,
 }
 
 impl Workspace {
-    pub fn new(scope: &str, path_to_config: String) -> Result<Self> {
+    pub fn new(scope: &str, path_to_config: String, ignore_queue: bool) -> Result<Self> {
         Ok(Self {
-            db: Database::open(scope, &path_to_config)?,
+            db: Database::open(scope, &path_to_config, ignore_queue)?,
             scope: scope.to_string(),
             path_to_config,
+            ignore_queue,
         })
     }
 
@@ -109,10 +111,12 @@ impl Workspace {
         }
         if let Some(previous_env) = env.propagated_from() {
             let patterns: Vec<_> = env.propagated_file_patterns().collect();
-            if let Some(env_state) =
-                self.db
-                    .get_target_propagated_state(&env.name, previous_env, &patterns)
-            {
+            if let Some(env_state) = self.db.get_target_propagated_state(
+                &env.name,
+                env.ignore_queue,
+                previous_env,
+                &patterns,
+            ) {
                 for (ident, state) in env_state.files.iter() {
                     let name = ident.name();
                     if patterns
@@ -185,6 +189,7 @@ impl Workspace {
         let current_commit = repo.gate_commit_hash();
         let database = Database::open_env(
             &self.path_to_config,
+            self.ignore_queue,
             &self.scope,
             &env.name,
             env.propagated_from(),
@@ -235,6 +240,7 @@ impl Workspace {
         };
         let database = Database::open_env(
             &self.path_to_config,
+            self.ignore_queue,
             &config.scope,
             &env.name,
             env.propagated_from(),
@@ -260,9 +266,12 @@ impl Workspace {
         let mut new_env_state = DeployState::new(commit.clone());
         if let Some(previous_env) = env.propagated_from() {
             let patterns: Vec<_> = env.propagated_file_patterns().collect();
-            if let Some(env_state) =
-                database.get_target_propagated_state(&env.name, previous_env, &patterns)
-            {
+            if let Some(env_state) = database.get_target_propagated_state(
+                &env.name,
+                env.ignore_queue,
+                previous_env,
+                &patterns,
+            ) {
                 new_env_state.propagated_head = Some(env_state.head_commit.clone());
                 for (ident, prev_state) in env_state.files.iter() {
                     let name = ident.name();
